@@ -2,6 +2,18 @@
 from threading import Thread
 
 def run_cmd(cmd):
+    """Run shell command and return command output.
+    
+    Examples:
+        >>> run_cmd("cd ..")
+        ''
+    
+    Args:
+        cmd (string): A shell command.
+    
+    Returns:
+        string: Command output.
+    """
     import subprocess
     return subprocess.getoutput(cmd)
 
@@ -147,3 +159,29 @@ def read_text_file(file_path):
 def display_text(content):
     from IPython.display import Code
     return Code(data=content, language="text")
+
+def remove_indent_space_in_file(file_path, block_line_begin, block_line_end, indent_space_number):
+    import fileinput
+    line_number = 0
+    with fileinput.FileInput(file_path, inplace=True) as f:
+        for line in f:
+            line_number = line_number + 1
+            if line_number >= block_line_begin and line_number <= block_line_end:
+                if len(line) < indent_space_number:
+                    print(line, end='')
+                else:
+                    new_line_content = line[indent_space_number:]
+                    print(new_line_content, end='')
+            else:
+                print(line, end='')
+
+def rstrip_space_in_file(file_path, line_number):
+    import fileinput
+    cur_line_number = 0
+    with fileinput.FileInput(file_path, inplace=True) as f:
+        for line in f:
+            cur_line_number = cur_line_number + 1
+            if line_number == cur_line_number:
+                print(line.rstrip() + "\n", end='')
+            else:
+                print(line, end='')
